@@ -416,35 +416,30 @@ def ellipse_calculation(ellipse_pos, start, end, start_dim, end_dim, minor_axis)
     abs_minor_axis = abs(minor_axis)
     abs_half_minor_axis = abs(0.5 * minor_axis)
 
-    arcsin_argument = end_dim / (2 * abs_half_minor_axis)
-    if arcsin_argument >= 1 or arcsin_argument <= -1:
+    if abs(end_dim)/abs_minor_axis > 1.0:
         print("arcsin error, end and half axis")
         print("end", end_dim, "minor_axis", minor_axis)
-        print("arcsin_argument", arcsin_argument)
+        print("arcsin_argument", end_dim / abs_minor_axis)
 
-    arcsin_argument = start_dim / (2 * abs_half_minor_axis)
-    if arcsin_argument >= 1 or arcsin_argument <= -1:
+    if abs(start_dim)/abs_minor_axis > 1.0:
         print("arcsin error, end and half axis")
         print("start", start_dim, "minor_axis", minor_axis)
-        print("arcsin_argument", arcsin_argument)
+        print("arcsin_argument", start_dim / abs_minor_axis)
 
     element_length = end - start
     if minor_axis > 0:
-        tmp_k = np.cos(np.arcsin(end_dim / (2 * abs_half_minor_axis))) / np.cos(
-            np.arcsin(start_dim / (2 * abs_half_minor_axis)))
+        tmp_k = np.cos(np.arcsin(end_dim / abs_minor_axis)) / np.cos(np.arcsin(start_dim / abs_minor_axis))
     else:
-        tmp_k = np.cos(np.arcsin(end_dim / (2 * abs_half_minor_axis))) / np.cos(
-            np.pi - np.arcsin(start_dim / (2 * abs_half_minor_axis)))
+        tmp_k = np.cos(np.arcsin(end_dim / abs_minor_axis)) / np.cos(np.pi - np.arcsin(start_dim / abs_minor_axis))
 
     focal_before = element_length / (1 + tmp_k)
     focal_after = element_length - focal_before
 
     if minor_axis > 0:
-        tmp_c = np.cos(np.arcsin(start_dim / (2 * abs_half_minor_axis))) * np.cos(
-            np.arcsin(start_dim / (2 * abs_half_minor_axis)))
+        tmp_c = np.cos(np.arcsin(start_dim / abs_minor_axis)) * np.cos(np.arcsin(start_dim / abs_minor_axis))
     else:
-        tmp_c = np.cos(np.pi - np.arcsin(start_dim / (2 * abs_half_minor_axis))) * np.cos(
-            np.pi - np.arcsin(start_dim / (2 * abs_half_minor_axis)))
+        tmp_c = np.cos(np.pi - np.arcsin(start_dim / abs_minor_axis)) * np.cos(
+            np.pi - np.arcsin(start_dim / abs_minor_axis))
 
     focus_L_in = -focal_before + np.sqrt(
         focal_before * focal_before * (1 / tmp_c) - abs_half_minor_axis * abs_half_minor_axis)
