@@ -648,6 +648,60 @@ class FixedInstrumentParameter(InstrumentParameter):
         return string
 
 
+class LosInstrumentParameter(InstrumentParameter):
+    """
+    Description of LOS parameter that needs to be calculated
+
+    Los instrument parameters are calculated after all other parameters are set
+    with the goal of preventing line of sight between given points in the
+    guide. These are controlled by the line of sight calculator. They appear
+    as an instrument parameter because they need to be transferred to the
+    simulation and tracked by logging.
+    """
+
+    def __init__(self, name):
+        """
+        Sets the name the los parameter
+
+        Parameters
+        ----------
+
+        name : str
+            Name of the FixedInstrumentParameter
+
+        """
+        super().__init__(name)
+
+    def get_value(self):
+        """
+        Return the value stored in the LosInstrumentParameter.
+        """
+
+        return self.value
+
+    def set_value(self, value):
+        """
+        Sets the stored value in the LosInstrumentParameter
+        """
+
+        self.value = value
+
+    def __repr__(self):
+        """
+        Returns a string describing this fixed parameter
+        """
+
+        string = "LOS parameter:     "
+        if self.category is None:
+            string += " " * 17
+        else:
+            string += self.category + " " * (17 - len(self.category))
+        string += str(self.name) + " "
+        string += " with value " + str(self.value)
+
+        return string
+
+
 class DependentInstrumentParameter(InstrumentParameter):
     """
     The DependentInstrumentParameter can be calculated from other InstrumentParameters
